@@ -17,6 +17,6 @@ def get_my_ip():
 
 ip = str(get_my_ip())
 
-main('makemigrations data')
-main('migrate data')
+# main('makemigrations data')
+# main('migrate data')
 main('runserver ' + ip + ':8000')
